Address class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

Address({String? city, String? country, String? line1, String? line2, String? postalCode, String? state})
Address.fromJson(Map<String, dynamic> json)
factory

Properties

city → String?
City, district, suburb, town, or village
final
country → String?
Two-letter country code ISO 3166-1 alpha-2
final
hashCode → int
The hash code for this object.
no setterinherited
line1 → String?
Address line 1 (e.g., street, PO Box, or company name)
final
line2 → String?
Address line 2 (e.g., apartment, suite, unit, or building)
final
postalCode → String?
ZIP or postal code
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → String?
State, county, province, or region
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited