BalanceTransaction class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

BalanceTransaction({required _BalanceTransactionObject object, required String id, required int amount, required int fee, required List<FeeDetails> feeDetails, required int net, required String currency})
BalanceTransaction.fromJson(Map<String, dynamic> json)
factory

Properties

amount → int
final
currency → String
final
fee → int
final
feeDetails → List<FeeDetails>
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
net → int
final
object → _BalanceTransactionObject
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited