ChargeEvent class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

ChargeEvent({required _EventObject object, required String id, required String type, required EventData<Charge> data})
ChargeEvent.fromJson(Map<String, dynamic> json)
factory

Properties

data ↔ EventData<Charge>
Object containing data associated with the event.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
Unique identifier for the object.
finalinherited
object → _EventObject
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Description of the event (e.g., invoice.created or charge.refunded).
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited