CheckoutSession class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

CheckoutSession({required String object, required String id, required List<PaymentMethodType> paymentMethodTypes, String? clientReferenceId, String? customer, String? paymentIntent})
CheckoutSession.fromJson(Map<String, dynamic> json)
factory

Properties

clientReferenceId → String?
final
customer → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
object → String
Doesn't work with enum because there is a dot in it.
final
paymentIntent → String?
final
paymentMethodTypes → List<PaymentMethodType>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited