CreateCheckoutSessionRequest class

Annotations
  • @JsonSerializable.new()

Constructors

CreateCheckoutSessionRequest({required String successUrl, required String cancelUrl, required List<PaymentMethodType> paymentMethodTypes, SessionMode? mode, String? clientReferenceId, String? customerEmail, String? customer, List<LineItem>? lineItems, BillingAddressCollection? billingAddressCollection, AutomaticTax? automaticTax, TaxIdCollection? taxIdCollection, PaymentIntentData? paymentIntentData, SubscriptionData? subscriptionData})
CreateCheckoutSessionRequest.fromJson(Map<String, dynamic> json)
factory

Properties

automaticTax → AutomaticTax?
Settings for automatic tax lookup for this session and resulting payments, invoices, and subscriptions.
final
billingAddressCollection → BillingAddressCollection?
Specify whether Checkout should collect the customer’s billing address.
final
cancelUrl → String
The URL the customer will be directed to if they decide to cancel payment and return to your website.
final
clientReferenceId → String?
A unique string to reference the Checkout Session. This can be a customer ID, a cart ID, or similar, and can be used to reconcile the Session with your internal systems.
final
customer → String?
ID of an existing customer, if one exists. The email stored on the customer will be used to prefill the email field on the Checkout page. If the customer changes their email on the Checkout page, the Customer object will be updated with the new email. If blank for Checkout Sessions in payment or subscription mode, Checkout will create a new customer object based on information provided during the payment flow.
final
customerEmail → String?
If provided, this value will be used when the Customer object is created. If not provided, customers will be asked to enter their email address. Use this parameter to prefill customer data if you already have an email on file. To access information about the customer once a session is complete, use the customer field.
final
hashCode → int
The hash code for this object.
no setterinherited
lineItems → List<LineItem>?
A list of items the customer is purchasing. Use this parameter to pass one-time or recurring Prices. One-time Prices in subscription mode will be on the initial invoice only.
final
mode → SessionMode?
The mode of the Checkout Session. Required when using prices or setup mode. Pass subscription if the Checkout Session includes at least one recurring item.
final
paymentIntentData → PaymentIntentData?
A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in payment mode.
final
paymentMethodTypes → List<PaymentMethodType>
A list of the types of payment methods (e.g., card) this Checkout Session can accept.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriptionData → SubscriptionData?
A subset of parameters to be passed to subscription creation for Checkout Sessions in subscription mode.
final
successUrl → String
The URL to which Stripe should send customers when payment or setup is complete. If you’d like access to the Checkout Session for the successful payment, read more about it in the guide on fulfilling orders.
final
taxIdCollection → TaxIdCollection?
Controls tax ID collection settings for the session.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited