CreateCustomerRequest class

Annotations
  • @JsonSerializable.new()

Constructors

CreateCustomerRequest({String? description, String? email, Map<String, String>? metadata, String? name, String? paymentMethod, String? phoneNumber})
CreateCustomerRequest.fromJson(Map<String, dynamic> json)
factory

Properties

description → String?
An arbitrary string that you can attach to a customer object. It is displayed alongside the customer in the dashboard.
finalinherited
email → String?
Customer’s email address. It’s displayed alongside the customer in your dashboard and can be useful for searching and tracking. This may be up to 512 characters.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
metadata → Map<String, String>?
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
finalinherited
name → String?
The customer’s full name or business name.
finalinherited
paymentMethod → String?
The ID of the PaymentMethod to attach to the customer.
finalinherited
phoneNumber → String?
The customer’s phone number.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited