CreatePortalSessionRequest class

Annotations
  • @JsonSerializable.new()

Constructors

CreatePortalSessionRequest({required String customer, String? returnUrl})
CreatePortalSessionRequest.fromJson(Map<String, dynamic> json)
factory

Properties

customer → String
The ID of an existing customer.
final
hashCode → int
The hash code for this object.
no setterinherited
returnUrl → String?
The default URL to redirect customers to when they click on the portal’s link to return to your website.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited