DataList<T> class

Annotations
  • @JsonSerializable.new()

Constructors

DataList({required _SubListObject object, required List<T> data, required bool hasMore, required String url})
DataList.fromJson(Map<String, dynamic> json, T fromJsonT(Object? json))
factory

Properties

data → List<T>
final
hashCode → int
The hash code for this object.
no setterinherited
hasMore → bool
final
object → _SubListObject
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(Object toJsonT(T value)) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited