EventData<T> class

Annotations
  • @JsonSerializable.new()

Constructors

EventData({required T object})
EventData.fromJson(Map<String, dynamic> json, T fromJsonT(Object? json))
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
object → T
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(Object toJsonT(T value)) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited