LineItem class

Annotations
  • @JsonSerializable.new()

Constructors

LineItem({List<String>? images, int? quantity, String? description, String? price, PriceData? priceData})
LineItem.fromJson(Map<String, dynamic> json)
factory

Properties

description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
images → List<String>?
final
price → String?
The ID of the Price or Plan object. One of price, price_data or amount is required.
final
priceData → PriceData?
Data used to generate a new Price object inline. One of price or price_data is required.
final
quantity → int?
The quantity of the line item being purchased. Quantity should not be defined when recurring.usage_type=metered.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited