PriceData class

Annotations
  • @JsonSerializable.new()

Constructors

PriceData({required String currency, String? product, int? unitAmount, ProductData? productData})
PriceData.fromJson(Map<String, dynamic> json)
factory

Properties

currency → String
Three-letter ISO currency code, in lowercase. Must be a supported currency.
final
hashCode → int
The hash code for this object.
no setterinherited
product → String?
The ID of the product that this price will belong to. One of product or product_data is required.
final
productData → ProductData?
Data used to generate a new product object inline. One of product or product_data is required.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unitAmount → int?
A non-negative integer in cents representing how much to charge. One of unit_amount or unit_amount_decimal is required.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited