ShippingSpecification class

Annotations
  • @JsonSerializable.new()

Constructors

ShippingSpecification({required Address address, required String name, String? carrier, String? phone, String? trackingNumber})
ShippingSpecification.fromJson(Map<String, dynamic> json)
factory

Properties

address → Address
Shipping Address
final
carrier → String?
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Recipient name
final
phone → String?
Recipient phone (including extension)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trackingNumber → String?
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited