Subscription class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

Subscription({required _SubscriptionObject object, required String id, required int created, required String customer, required SubscriptionStatus status, required DataList<SubscriptionItem> items, required DateTime currentPeriodStart, required DateTime currentPeriodEnd, Map<String, dynamic>? metadata})
Subscription.fromJson(Map<String, dynamic> json)
factory

Properties

created → int
Time at which the object was created. Measured in seconds since the Unix epoch.
final
currentPeriodEnd → DateTime
End of the current period that the subscription has been invoiced for. At the end of this period, a new invoice will be created.
final
currentPeriodStart → DateTime
Start of the current period that the subscription has been invoiced for.
final
customer → String
ID of the customer who owns the subscription.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
Unique identifier for the object.
final
items → DataList<SubscriptionItem>
List of subscription items, each with an attached price.
final
metadata → Map<String, dynamic>?
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
final
object → _SubscriptionObject
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → SubscriptionStatus
Possible values are incomplete, incomplete_expired, trialing, active, past_due, canceled, or unpaid.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited