SubscriptionItem class

Annotations
  • @JsonSerializable.new()

Constructors

SubscriptionItem({required _SubscriptionItemObject object, required String id, required Price price, required String subscription})
SubscriptionItem.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
Unique identifier for the object.
final
object → _SubscriptionItemObject
final
price → Price
The price the customer is subscribed to.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscription → String
The subscription this subscription_item belongs to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited